@@ -21,25 +21,26 @@
 #include "k3bthememanager.h"
 #include "k3bversion.h"
 
-#include <QCursor>
-#include <QDragEnterEvent>
-#include <QDropEvent>
-#include <QMouseEvent>
-#include <QPainter>
-#include <QPaintEvent>
-#include <QResizeEvent>
-#include <QShowEvent>
-#include <QStyle>
-#include <QTextDocument>
+#include <KConfigCore/KConfigGroup>
+#include <KCoreAddons/KAboutData>
+#include <KIconThemes/KIconLoader>
+#include <KI18n/KLocalizedString>
+#include <KXmlGui/KActionCollection>
 
-#include <KActionCollection>
-#include <KAboutData>
-#include <KConfigGroup>
-#include <KGlobal>
-#include <KGlobalSettings>
-#include <KLocale>
-#include <KMenu>
-#include <KUrl>
+#include <QtCore/QMimeData>
+#include <QtCore/QUrl>
+#include <QtGui/QIcon>
+#include <QtGui/QCursor>
+#include <QtGui/QDragEnterEvent>
+#include <QtGui/QDropEvent>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPainter>
+#include <QtGui/QPaintEvent>
+#include <QtGui/QResizeEvent>
+#include <QtGui/QShowEvent>
+#include <QtGui/QTextDocument>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QStyle>
 
 namespace {
 
@@ -80,14 +81,13 @@ K3b::WelcomeWidget::WelcomeWidget( MainWindow* mainWindow, QWidget* parent )
 
     setAcceptDrops( true );
     setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
-    
+
     m_rows = m_cols = 1;
 
     m_buttonMore = new K3b::FlatButton( i18n("More actions..."), this );
-    
+
     connect( m_buttonMore, SIGNAL(pressed()), this, SLOT(slotMoreActions()) );
     connect( k3bappcore->themeManager(), SIGNAL(themeChanged()), this, SLOT(slotThemeChanged()) );
-    connect( KGlobalSettings::self(), SIGNAL(appearanceChanged()), this, SLOT(update()) );
 
     slotThemeChanged();
 }
@@ -216,7 +216,7 @@ void K3b::WelcomeWidget::repositionButtons()
     QRect rect( leftMargin + 2, topOffset + (row*(m_buttonSize.height()+BUTTON_SPACING)) + 2,
                 m_cols*(m_buttonSize.width()+BUTTON_SPACING) - BUTTON_SPACING, m_buttonMore->height() );
     m_buttonMore->setGeometry( QStyle::visualRect( layoutDirection(), contentsRect(), rect ) );
-    
+
     setMinimumHeight( heightForWidth( width() ) );
 }
 
@@ -227,7 +227,7 @@ int K3b::WelcomeWidget::heightForWidth( int width ) const
     m_infoText->setTextWidth( width );
     int h = ( int )m_infoText->size().height();
     m_infoText->setTextWidth( ow );
-    
+
     int cols, rows;
     calculateButtons( width, m_actions.count(), m_buttonSize.width(), cols, rows );
     int height = MARGIN +
@@ -239,6 +239,15 @@ int K3b::WelcomeWidget::heightForWidth( int width ) const
 }
 
 
+bool K3b::WelcomeWidget::event( QEvent *event )
+{
+    if( event->type() == QEvent::StyleChange ) {
+        update();
+    }
+    return QWidget::event( event );
+}
+
+
 void K3b::WelcomeWidget::resizeEvent( QResizeEvent* e )
 {
     m_infoText->setTextWidth( width() - MARGIN );
@@ -260,9 +269,11 @@ void K3b::WelcomeWidget::slotThemeChanged()
                                           .arg(theme->foregroundColor().name()) );
     }
 
-    m_header->setHtml( "<html><body align=\"center\">" + i18n("Welcome to K3b - The CD and DVD Kreator") + "</body></html>" );
-    m_infoText->setHtml( QString::fromUtf8("<html><body align=\"center\">K3b %1 &copy; 1999&ndash;2010 Sebastian Trüg et al.</body></html>")
-                         .arg(KGlobal::mainComponent().aboutData()->version()) );
+    m_header->setHtml( "<html><body align=\"center\">" + i18n("Welcome to K3b &ndash; The CD, DVD, and Blu-ray Kreator") + "</body></html>" );
+    m_infoText->setHtml( "<html><body align=\"center\">" 
+                         + i18n("K3b %1 Copyright &copy; 1998&ndash;2017 K3b authors",
+                                KAboutData::applicationData().version())
+                         + "</body></html>" );
     setMinimumWidth( 2*MARGIN + qMax(( int )m_header->idealWidth(), m_buttonSize.width()) );
     updateBgPix();
     update();
@@ -271,7 +282,7 @@ void K3b::WelcomeWidget::slotThemeChanged()
 
 void K3b::WelcomeWidget::slotMoreActions()
 {
-    KMenu popup;
+    QMenu popup;
 
     for ( int i = 0; s_allActions[i]; ++i ) {
         if ( s_allActions[i][0] == '_' ) {
@@ -348,13 +359,13 @@ void K3b::WelcomeWidget::dragEnterEvent( QDragEnterEvent* event )
 
 void K3b::WelcomeWidget::dropEvent( QDropEvent* e )
 {
-    KUrl::List urls;
+    QList<QUrl> urls;
     Q_FOREACH( const QUrl& url, e->mimeData()->urls() )
     {
         urls.push_back( url );
     }
 
-    QMetaObject::invokeMethod( m_mainWindow, "addUrls", Qt::QueuedConnection, Q_ARG( KUrl::List, urls ) );
+    QMetaObject::invokeMethod( m_mainWindow, "addUrls", Qt::QueuedConnection, Q_ARG( QList<QUrl>, urls ) );
 }
 
 
@@ -393,7 +404,7 @@ void K3b::WelcomeWidget::mousePressEvent ( QMouseEvent* e )
 {
     if( e->button() == Qt::RightButton ) {
         QMap<QAction*, QAction*> map;
-        KMenu addPop;
+        QMenu addPop;
         addPop.setTitle( i18n("Add Button") );
 
         QAction* firstAction = 0;
@@ -416,14 +427,14 @@ void K3b::WelcomeWidget::mousePressEvent ( QMouseEvent* e )
 
         QWidget* widgetAtPos = childAt(e->pos());
         if( widgetAtPos && widgetAtPos->inherits( "K3b::FlatButton" ) ) {
-            KMenu pop;
+            QMenu pop;
             removeAction = pop.addAction( SmallIcon("list-remove"), i18n("Remove Button") );
             if ( addPop.actions().count() > 0 )
                 pop.addMenu( &addPop );
             r = pop.exec( e->globalPos() );
         }
         else {
-            addPop.addTitle( addPop.title(), firstAction );
+            addPop.insertSection( firstAction, addPop.title() );
             r = addPop.exec( e->globalPos() );
         }
 
@@ -436,4 +447,4 @@ void K3b::WelcomeWidget::mousePressEvent ( QMouseEvent* e )
     }
 }
 
-#include "k3bwelcomewidget.moc"
+
